<?php

namespace Drupal\registered_organisations;

/**
 * Interface for Organisation Register Plugin.
 */
interface OrganisationRegisterInterface {

  /**
   * Cache prefix.
   *
   * @var string
   */
  const CACHE_PREFIX = 'registered_organisations';

  /**
   * The rate limit buffer in seconds.
   *
   * If rate limiting is hit by any of the registers pause requests for the
   * specified amount of time.
   *
   * @var int
   */
  const RATE_LIMIT_BUFFER = 60;

  /**
   * Get an organisation by ID.
   *
   * @param string $id
   *   An organisation ID to be looked up.
   *
   * @throws RegisterException
   *   If the register could not be retrieved or accessed.
   * @throws DataException
   *   If there are errors with the data that is retrieved.
   *
   * @return OrganisationInterface|null
   *   An organisation profile object.
   */
  public function getOrganisation(string $id): OrganisationInterface|null;

  /**
   * Find an organisation by name.
   *
   * @param string $name
   *   An organisation name to be looked up.
   * @param bool $active
   *   If true, return only active organisations.
   *
   * @throws RegisterException
   *   If the register could not be retrieved or accessed.
   * @throws DataException
   *   If there are errors with the data that is retrieved.
   *
   * @return OrganisationInterface[]
   *   An array of matched organisation profile objects.
   */
  public function findOrganisation(string $name): array;

  /**
   * Process the data from any raw input to a format suitable for output.
   *
   * @param string $key
   *   This element's key within the data array.
   * @param mixed $value
   *   The data value to process.
   *
   * @return mixed
   */
  public function process(string $key, mixed $value): mixed;

}
